package com.diagbot.facade;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.diagbot.dto.SearchEvaluatorDTO;
import com.diagbot.dto.PhysicalInfoDTO;
import com.diagbot.entity.Evaluator;
import com.diagbot.entity.PhysicalInfo;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.enums.SexEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.EvaluatorServiceImpl;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.DateUtil;
import com.diagbot.util.ListUtil;
import com.diagbot.util.RegexValidateUtil;
import com.diagbot.vo.AddEvaluatorVO;
import com.diagbot.vo.SearchEvaluatorVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @author: gaodm
 * @time: 2019/5/30 10:41
 */
@Component
public class EvaluatorFacade extends EvaluatorServiceImpl {
    @Autowired
    private PhysicalInfoFacade physicalInfoFacade;

    public Boolean addEvaluator(AddEvaluatorVO addDeptInfoVO) {
        //参数验证
        if (!RegexValidateUtil.checkMobileNumber(addDeptInfoVO.getPhone())) {
            throw new CommonException(CommonErrorCode.PARAM_IS_ERROR,
                    "请输入正确的手机号");
        }
        if (null == SexEnum.getName(addDeptInfoVO.getSex())) {
            throw new CommonException(CommonErrorCode.PARAM_IS_ERROR,
                    "请输入正确的性别类型");
        }

        Evaluator evaluator = new Evaluator();
        BeanUtil.copyProperties(addDeptInfoVO, evaluator);
        //计算
        //保存结果
        Date now = DateUtil.now();
        evaluator.setIsDeleted(IsDeleteEnum.N.getKey());
        evaluator.setGmtCreate(now);
        evaluator.setGmtModified(now);
        Boolean res = this.save(evaluator);
        if (!res) {
            throw new CommonException(CommonErrorCode.INSERT_DATA_FAILED, "评估结果提交失败！");
        }
        return res;
    }

    public IPage<SearchEvaluatorDTO> getEvaluatorPage(SearchEvaluatorVO searchEvaluatorVO) {
        IPage<SearchEvaluatorDTO> res = this.getEvaluators(searchEvaluatorVO);
        if (ListUtil.isNotEmpty(res.getRecords())){
            Map<String, PhysicalInfo> pMap = physicalInfoFacade.getPhysicalMap();

            for (SearchEvaluatorDTO searchEvaluatorDTO : res.getRecords()){
                String[] physicalTypes = searchEvaluatorDTO.getPhysicalTypes().split(",");
                List<PhysicalInfoDTO> physicalInfoDTOList = ListUtil.newArrayList();
                for (String s : physicalTypes){
                    PhysicalInfoDTO  physicalInfoDTO = new PhysicalInfoDTO();
                    if (null != pMap.get(s)){
                        BeanUtil.copyProperties(pMap.get(s), physicalInfoDTO);
                        physicalInfoDTOList.add(physicalInfoDTO);
                    }
                }
                searchEvaluatorDTO.setPhysicalInfoDTOList(physicalInfoDTOList);
            }
        }
        return res;
    }
}
